# Change log

## 0.0.2
*   \[Breaking\] Rename `ocr` prpoerty of `Page` as `text`.
*   Introduce `text` property to `Work` and `Article`.
*   Re-use djvu file generated by earlier run. Add `force` argument to avoid reuse.
*   Parse the `IMAGE_SOURCE` metadata.
*   Expand testing to py37, py38

## 0.0.1

*   Initial PyPI release.
